@@ -4,26 +4,21 @@ import doctest
 import enum
 import functools
 import json
-import logging
 import os
 import pathlib
 import re
 import subprocess
 import sys
-from typing import Union, Literal
+from typing import Literal, Union
 
+import np_logging
 import requests
 
-if __name__ == "__main__":
-    from data_getters import lims_data_getter
-    from lims2 import SessionInfo
-    import paths
-else:
-    from .data_getters import lims_data_getter
-    from .lims2 import SessionInfo
-    from . import paths 
+from np_session.components import paths
+from np_session.databases.data_getters import lims_data_getter
+from np_session.databases.lims2 import LIMS2SessionInfo 
 
-logger = logging.getLogger(__name__)
+logger = np_logging.getLogger(__name__)
 
 PathLike = Union[str, bytes, os.PathLike, pathlib.Path]
 # https://peps.python.org/pep-0519/#provide-specific-type-hinting-support
@@ -67,7 +62,7 @@ def is_valid_session_id(session_id: int | str) -> bool:
     >>> is_valid_session_id('abcdefg')
     False
     """
-    return bool(SessionInfo(str(session_id)))
+    return bool(LIMS2SessionInfo(str(session_id)))
 
 
 def lims_session_id(path: PathLike) -> str | None:
@@ -143,7 +138,7 @@ def folder_from_lims_id(path: PathLike) -> str | None:
     session_id = lims_session_id(path)
     if session_id is None:
         return None
-    return SessionInfo(session_id).folder
+    return LIMS2SessionInfo(session_id).folder
 
 
 @functools.lru_cache(maxsize=None)
